@@ -37,6 +37,7 @@
 #include "substituteexpression.h"
 #include "expressionstream.h"
 #include "matrix.h"
+#include "commands/realpower.h"
 #include "commands/listcommands.h"
 #include "commands/vectorcommands.h"
 #include "commands/matrixcommands.h"
@@ -163,6 +164,7 @@ Analyzer::~Analyzer()
 
 void Analyzer::registerBuiltinMethods()
 {
+    m_builtin.insertFunction(RealPower::id, RealPower::type, new RealPower);
     m_builtin.insertFunction(RangeCommand::id, RangeCommand::type, new RangeCommand);
     m_builtin.insertFunction(VectorCommand::id, VectorCommand::type, new VectorCommand);
     m_builtin.insertFunction(MatrixCommand::id, MatrixCommand::type, new MatrixCommand);
@@ -1102,8 +1104,7 @@ Object* Analyzer::calcMap(const Apply* c)
     
     List::iterator it=l->begin(), itEnd=l->end();
     for(; it!=itEnd; ++it) {
-        QVector<Object*> args=QVector<Object*>(1, *it);
-        *it = calcCallFunction(f, args, f);
+        *it = calcCallFunction(f, { *it }, f);
     }
     
     delete f;
